==> file_compressor_field-2.0.0.tar.gz: file_compressor_field/src/Form/FileCompressorRebuildForm.php <==
<?php

namespace Drupal\file_compressor_field\Form;

use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Manually Rebuild File Compressor fields..
 */
class FileCompressorRebuildForm extends FormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The field manager.
   *
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected $entityFieldManager;

  /**
   * The field manager.
   *
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected $entityTypeBundleInfo;

  /**
   * Constructs a new FileCompressorRebuildForm.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager
   *   The entity field manager.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entity_type_bundle_info
   *   The entity type bundle info.
   */
  final public function __construct(EntityTypeManagerInterface $entity_type_manager, EntityFieldManagerInterface $entity_field_manager, EntityTypeBundleInfoInterface $entity_type_bundle_info) {
    $this->entityTypeManager = $entity_type_manager;
    $this->entityFieldManager = $entity_field_manager;
    $this->entityTypeBundleInfo = $entity_type_bundle_info;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('entity_field.manager'),
      $container->get('entity_type.bundle.info')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'file_compressor_rebuild';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $definitions = $this->entityFieldManager->getFieldMapByFieldType('file_compressor');

    $options = [];
    foreach ($definitions as $entity_type_id => $field_definitions) {
      $entity_type = $this->entityTypeManager->getDefinition($entity_type_id);
      $bundle_info = $this->entityTypeBundleInfo->getBundleInfo($entity_type_id);
      foreach ($field_definitions as $field_name => $field_map) {
        foreach ($field_map['bundles'] as $bundle) {
          $bundle_definitions = $this->entityFieldManager->getFieldDefinitions($entity_type_id, $bundle);
          $option_key = implode('|', [$entity_type_id, $bundle]);
          if (!isset($options[$option_key])) {
            $options[$option_key] = [
              $bundle_definitions[$field_name]->getLabel(),
              $entity_type->getLabel(),
              $bundle_info[$bundle]['label'],
            ];
          }
          else {
            $options[$option_key][0] = $options[$option_key][0] . ', ' . $bundle_definitions[$field_name]->getLabel();
          }
        }
      }
    }

    $header = [$this->t('Field Name'), $this->t('Entity type'), $this->t('Bundle')];

    $form['rebuild'] = [
      '#type' => 'tableselect',
      '#header' => $header,
      '#options' => $options,
      '#empty' => $this->t('No content available.'),
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Rebuild Compressed files'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $selected_fields = array_filter($form_state->getValue('rebuild'));
    if (empty($selected_fields)) {
      $form_state->setErrorByName('rebuild', $this->t('Please select at least one field to update.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $fields = array_filter($form_state->getValue('rebuild'));
    foreach ($fields as $field) {
      [$entity_type_name, $bundle_name] = explode('|', $field);
      $entity_type = $this->entityTypeManager->getDefinition($entity_type_name);

      $query = $this->entityTypeManager->getStorage($entity_type_name)->getQuery();
      $query->accessCheck(FALSE);
      if ($type = $entity_type->getKey('bundle')) {
        $query->condition($type, $bundle_name);
      }
      $result = $query->execute();
      if (!empty($result)) {
        $storage = $this->entityTypeManager->getStorage($entity_type);
        $entities = $storage->loadMultiple($result);
        foreach ($entities as $entity) {
          $entity->save();
        }
      }
    }
  }

}

==> file_compressor_field-2.1.0.tar.gz: file_compressor_field/src/Form/FileCompressorRebuildForm.php <==
<?php

namespace Drupal\file_compressor_field\Form;

use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Manually Rebuild File Compressor fields.
 */
class FileCompressorRebuildForm extends FormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The field manager.
   *
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected $entityFieldManager;

  /**
   * The field manager.
   *
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected $entityTypeBundleInfo;

  /**
   * Constructs a new FileCompressorRebuildForm.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager
   *   The entity field manager.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entity_type_bundle_info
   *   The entity type bundle info.
   */
  final public function __construct(EntityTypeManagerInterface $entity_type_manager, EntityFieldManagerInterface $entity_field_manager, EntityTypeBundleInfoInterface $entity_type_bundle_info) {
    $this->entityTypeManager = $entity_type_manager;
    $this->entityFieldManager = $entity_field_manager;
    $this->entityTypeBundleInfo = $entity_type_bundle_info;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('entity_field.manager'),
      $container->get('entity_type.bundle.info')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'file_compressor_rebuild';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $definitions = $this->entityFieldManager->getFieldMapByFieldType('file_compressor');

    $options = [];
    foreach ($definitions as $entity_type_id => $field_definitions) {
      $entity_type = $this->entityTypeManager->getDefinition($entity_type_id);
      $bundle_info = $this->entityTypeBundleInfo->getBundleInfo($entity_type_id);
      foreach ($field_definitions as $field_name => $field_map) {
        foreach ($field_map['bundles'] as $bundle) {
          $bundle_definitions = $this->entityFieldManager->getFieldDefinitions($entity_type_id, $bundle);
          $option_key = implode('|', [$entity_type_id, $bundle]);
          if (!isset($options[$option_key])) {
            $options[$option_key] = [
              $bundle_definitions[$field_name]->getLabel(),
              $entity_type->getLabel(),
              $bundle_info[$bundle]['label'],
            ];
          }
          else {
            $options[$option_key][0] = $options[$option_key][0] . ', ' . $bundle_definitions[$field_name]->getLabel();
          }
        }
      }
    }

    $header = [$this->t('Field Name'), $this->t('Entity type'), $this->t('Bundle')];

    $form['rebuild'] = [
      '#type' => 'tableselect',
      '#header' => $header,
      '#options' => $options,
      '#empty' => $this->t('No content available.'),
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Rebuild Compressed files'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $selected_fields = array_filter($form_state->getValue('rebuild'));
    if (empty($selected_fields)) {
      $form_state->setErrorByName('rebuild', $this->t('Please select at least one field to update.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $fields = array_filter($form_state->getValue('rebuild'));
    foreach ($fields as $field) {
      [$entity_type_name, $bundle_name] = explode('|', $field);
      $entity_type = $this->entityTypeManager->getDefinition($entity_type_name);

      $query = $this->entityTypeManager->getStorage($entity_type_name)->getQuery();
      $query->accessCheck(FALSE);
      if ($type = $entity_type->getKey('bundle')) {
        $query->condition($type, $bundle_name);
      }
      $result = $query->execute();
      if (!empty($result)) {
        $storage = $this->entityTypeManager->getStorage($entity_type);
        $entities = $storage->loadMultiple($result);
        foreach ($entities as $entity) {
          $entity->save();
        }
      }
    }
  }

}
